function MPprintSpec (NCof, dev, BSpec, fid)
% This routine prints the design parameters for a min-phase FIR filter.

% $Id: MPprintSpec.m,v 1.3 2009/07/06 18:19:46 pkabal Exp $

if (~ exist ('fid', 'var'))
  fid = 1;
end

dBV = @(x)(20 * log10 (x));

DFM_MP = 'Minimum Phase FIR Filter';
DIMF_Pars = ' No. Coef: %d\n';
DFMP_MPheader = ...
'           Freq.      Value           Limits     Deviation  Dev dB';
DFMP_BandS = 'Band %2d:%7.4f %10.3g ';
DFMP_BandC = '        %7.4f %10.3g ';

% Preamble
fprintf (fid, '%s\n', DFM_MP);
fprintf (fid, DIMF_Pars, NCof);
fprintf (fid, '%s\n', DFMP_MPheader);

% Convert linear phase filter specs to min-phase filter specs
NBand = length (BSpec);
for (k = 1:NBand)
  MPSpec(k).f = BSpec(k).f;
  MPSpec(k).V = sqrt (BSpec(k).V);
  MPSpec(k).LL = sqrt (BSpec(k).LL);
  MPSpec(k).UL = sqrt (BSpec(k).UL);
  devW = dev ./ BSpec(k).W;
  MPSpec(k).excL = sqrt (max (BSpec(k).V - devW, BSpec(k).LL));
  MPSpec(k).excU = sqrt (min (BSpec(k).V + devW, BSpec(k).UL));
end

% Design specifications
for (k = 1:NBand)

  NVal = length (MPSpec(k).f);
  for (i = 1:NVal)

    if (i == 1)
      fprintf (fid, DFMP_BandS, k, MPSpec(k).f(i), MPSpec(k).V(i));
    else
      fprintf (fid, DFMP_BandC,    MPSpec(k).f(i), MPSpec(k).V(i));
    end

    % Limits
    if (isinf (MPSpec(k).LL(i)))
      fprintf (fid, '      ---- ');
    else
      fprintf (fid, '%10.3g ', MPSpec(k).LL(i));
    end
    if (isinf (BSpec(k).UL(i)))
      fprintf (fid, '      ---- ');
    else
      fprintf (fid, '%10.3g ', MPSpec(k).UL(i));
    end

    % The printed deviation in dB is the larger of the dB value of
    % the plus excursion or the minus excursion.
    MPdevWM = max (MPSpec(k).excU(i) - MPSpec(k).V(i), ...
                   MPSpec(k).V(i) - MPSpec(k).excL(i));
    fprintf (fid, '%9.2g', MPdevWM);
    if (MPdevWM > 0)
      if (MPSpec(k).V(i) ~= 0 && MPSpec(k).excL(i) > 0)
        RU = MPSpec(k).excU(i) / MPSpec(k).V(i);
        RL = MPSpec(k).V(i) / MPSpec(k).excL(i);
        devdB = dBV (max (RU, RL));
      else
        devdB = dBV (MPdevWM);
      end
      fprintf (fid, ' %7.2f', devdB);
    else
      fprintf (fid, '    ****');
    end
    fprintf (fid, '\n');

  end
end

return
